############################################
Gravitational-wave Detector Characterisation
############################################

GWDetChar is a python package for for gravitational-wave detector
characterisation and data quality.

|PyPI version| |Conda version|

|DOI| |License| |Supported Python versions|

|Build Status| |Coverage Status| |Documentation Status|

https://gwdetchar.readthedocs.io

------------
Installation
------------

GWDetChar is best installed with `conda`_:

.. code:: bash

   conda install -c conda-forge gwdetchar

but can also be installed with `pip`_:

.. code:: bash

   python -m pip install gwdetchar

------------
Contributing
------------

All code should follow the Python Style Guide outlined in `PEP 0008`_;
users can use the `flake8`_ package to check their code for style issues
before submitting.

See `the contributions guide`_ for the recommended procedure for
proposing additions/changes.

.. _PEP 0008: https://www.python.org/dev/peps/pep-0008/
.. _flake8: http://flake8.pycqa.org
.. _the contributions guide: https://github.com/gwdetchar/gwdetchar/blob/master/CONTRIBUTING.md
.. _conda: https://conda.io
.. _pip: https://pip.pypa.io/en/stable/


.. |PyPI version| image:: https://badge.fury.io/py/gwdetchar.svg
   :target: http://badge.fury.io/py/gwdetchar
.. |Conda version| image:: https://img.shields.io/conda/vn/conda-forge/gwdetchar.svg
   :target: https://anaconda.org/conda-forge/gwdetchar/
.. |DOI| image:: https://zenodo.org/badge/36960054.svg
   :target: https://zenodo.org/badge/latestdoi/36960054
.. |License| image:: https://img.shields.io/pypi/l/gwdetchar.svg
   :target: https://choosealicense.com/licenses/gpl-3.0/
.. |Supported Python versions| image:: https://img.shields.io/pypi/pyversions/gwdetchar.svg
   :target: https://pypi.org/project/gwdetchar/
.. |Build Status| image:: https://github.com/gwdetchar/gwdetchar/actions/workflows/build.yml/badge.svg
   :target: https://github.com/gwdetchar/gwdetchar/actions/workflows/build.yml
.. |Coverage Status| image:: https://codecov.io/gh/gwdetchar/gwdetchar/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/gwdetchar/gwdetchar
.. |Documentation Status| image:: https://readthedocs.org/projects/gwdetchar/badge/?version=latest
   :target: https://gwdetchar.readthedocs.io/en/latest/?badge=latest
